Suitcase uses
[native namespace packages](https://packaging.python.org/guides/packaging-namespace-packages/#native-namespace-packages).

This directory *must not* contain an ``__init__.py`` or it will break this
package and all other suitcase namespace packages.
